Backup and Restore
==================

The default MCIWB Minecraft server provides a backup and restore facility
described here (TODO).

If you are running your own server it is useful to add backup and restore 
capability and MCIWB supports this with a little configuration.

TODO